@@ -38,7 +38,7 @@ Email.innerHTML =  client_mail;
 document.getElementById('pi_id').innerHTML = client_id;
 document.getElementById('pi_fc').innerHTML = client_fc.split(' ')[0];
 
-newElement({element:"button",cls:['uk-button','uk-button-primary','mdi','mdi-bike','uk-button-small'],attr:[['key-title','cli_new_session'],['style','font-size:16pt'],['onclick',`new_session_id(${client_id})`]]},document.getElementById('pi_newSession'))
+newElement({element:"button",cls:['quad-35','uk-button','uk-button-primary','mdi','mdi-bike','uk-button-small'],attr:[['key-title','cli_new_session'],['style','font-size:16pt'],['onclick',`new_session_id(${client_id})`]]},document.getElementById('pi_newSession'))
 
 gen_session_list()
 
@@ -82,6 +82,12 @@ function toProtokoll(id){
   localStorage.setItem('session',`restart ${id}`);
   location.pathname = '/production/protokoll.tcls';
 }
+
+function toGalerie(id){
+  localStorage.setItem('session',`restart ${id}`);
+  location.pathname = '/production/galerie.tcls';
+}
+
 var NnameI,VnameI,EmailI
 var cli_edit = document.getElementById('cli_edit')
 function editData() {
@@ -120,4 +126,4 @@ function editData() {
   }
 translatejs();
 
-}
\ No newline at end of file
+}
