@@ -48,6 +48,7 @@ let sda_frame2 = `${host}/sattelbild?image=blank`;
 let hocker_frame = `${host}/sattelbild?image=blank`;
 let setting = new Object();
 let galerie_image_info;
+let gal=[]
 var data;
 
 let note = localStorage.getItem('session_note')
@@ -208,6 +209,7 @@ document.getElementById('note_session').onchange = function() {
     sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
   }
   sattelanalyse.send(`sql UPDATE sessions SET notes='${document.getElementById('note_session').value}' WHERE session_id=${sess}`)
+  localStorage.setItem('session_note',document.getElementById('note_session').value)
 }
 // console.log($(window).height()>$(window).width,$(window).height(),'>',)
 if($(window).height()>$(window).width()){
@@ -221,16 +223,20 @@ if($(window).height()>$(window).width()){
 /* Checking if the cable is connected or not. If it is not connected, it will show a modal. */
 var conBT = setInterval(function () {
   if(cable==false){
-  UIkit.modal($("#modal-connect-with-bluetooth")).show();
+  connectBt()
+  //UIkit.modal($("#modal-connect-with-bluetooth")).show();
   let append = document.getElementsByClassName('navbar-right')[0];
   let li = newElement({element:'li',cls:['nav-item']},append);
-  let btn = newElement({element:'button',cls:['uk-button','uk-button-small','uk-button-default','ico-16', 'mdi', 'mdi-bluetooth'],attr:[['onclick','UIkit.modal($("#modal-connect-with-bluetooth")).show()'],['key-title','sda_bluetooth_con']]},li)
+  let btn = newElement({element:'button',cls:['uk-button','uk-button-small','uk-button-default','ico-16', 'mdi', 'mdi-connection'],attr:[['onclick','connectBt()'],['key-title','sda_bluetooth_con']]},li)
   }
   clearInterval(conBT);
 }, 1000);
 translatejs();
 }
 
+function connectBt() {
+  OpenModDialog({type:'success',title:["sda_blue_con_question"],msg:["sda_blue_con_text"],master_btn:['sda_blue_verbinden','con_bluetooth()'],slave_btn:['button_cancel']})
+}
 /**
  * "When the user clicks the save button, show the save mask modal."
  *
@@ -305,6 +311,7 @@ function save_rec(num) {
   info.notes = $(`#notes${num}`)[0].value;
   // console.log(`recording store ${num} ${JSON.stringify(info)}`);
   sattelanalyse.send(`recording store ${num} ${JSON.stringify(info)}`);
+  
   //TODO: Dialog nach aktuellem CI erstellen und übersetzen!
   UIkit.notification({message: `${aLangKeys[lang]['save_data']}`})
 }
@@ -315,6 +322,9 @@ function save_rec(num) {
  */
 function load_rec(num) {
   load_num = num
+  let btn = document.getElementById('img_select_btn');
+  btn.setAttribute('disabled','')
+
   // console.log('load ',num);
   if(localStorage.getItem('session').split(' ')[0]=='restart'){
   onsqlresult = RowImg
@@ -411,15 +421,27 @@ function run_Sitzknochen(num) {
  * @param event - The event object.
  * @returns The return value of the function is the string "Are you sure you want to leave the page?"
  */
-const onConfirmRefresh = function (event) {
-  event.preventDefault();
-  return event.returnValue = "Are you sure you want to leave the page?";
-}
+//const onConfirmRefresh = function (event) {
+//  event.preventDefault();
+//  if(event.returnValue == true)
+//  console.log(event);
+
+//  return event.returnValue = true;
+//  //sattelanalyse.send('btdisconnect')
+
+//}
 
 /* Adding an event listener to the window object. The event listener is listening for the beforeunload
 event. When the event is triggered, the onConfirmRefresh function is called. */
-window.addEventListener("beforeunload", onConfirmRefresh, { capture: true });
+//window.addEventListener("beforeunload", onConfirmRefresh, { capture: true });
 
+/* The above code is a JavaScript code that is binding two events to the window object. */
+$( window ).bind( 'beforeunload' , function( event ) {
+  event.preventDefault();
+  return '';
+} ).bind( 'unload', function( event ) {
+  sattelanalyse.send('btdisconnect')
+} );
 /**
  * It sets up the websocket connection and defines what happens when the server sends a message
  */
@@ -501,7 +523,7 @@ function run_Sattelanalyse() {
           /* Checking if the data.btevent is equal to "error" and if it is, it will hide the modal and
           display the error message. */
           if (data.btevent === "error") {
-          UIkit.modal($("#modal-connect-bluetooth")).hide();
+          //UIkit.modal($("#modal-connect-bluetooth")).hide();
           error_msg(data);
           }
           // data.btevent = "ambiguity"
@@ -523,15 +545,19 @@ function run_Sattelanalyse() {
           /* A JavaScript code that is executed when the event "status" is received. */
           if(data.btevent === "status"){
             if(data.devices[0]){
-            let e1 = document.getElementById('link_bolt');
-            e1.removeAttribute('onclick');
-            let e2 = document.getElementById("bolt");
-            e2.classList.remove('mdi-link-variant-off');
-            e2.classList.add('mdi-link-variant');
-            e2.style.color="green";
-            $('#bt_verbindung_hergestellt')[0].innerHTML = 'Verbunden';
-            $('#bt_verbindung_text')[0].innerHTML = `Gerätename: ${data.devices[0].name}<br>Macadresse: ${data.devices[0].address}`;
-            }
+            //let e1 = document.getElementById('link_bolt');
+            //e1.removeAttribute('onclick');
+            //let e2 = document.getElementById("bolt");
+            //e2.classList.remove('mdi-link-variant-off');
+            //e2.classList.add('mdi-link-variant');
+            //e2.style.color="green";
+            OpenModDialog({type:'success',title:["sda_blue_verbunden"],msg:`Gerätename: ${data.devices[0].name}<br>Macadresse: ${data.devices[0].address}`,master_btn:['button_ok']})
+
+            //$('#bt_verbindung_hergestellt')[0].innerHTML = 'Verbunden';
+            //$('#bt_verbindung_text')[0].innerHTML = `Gerätename: ${data.devices[0].name}<br>Macadresse: ${data.devices[0].address}`;
+            //let btn = newElement({element:'button',cls:['uk-button' ,'uk-button-primary' ,'uk-modal-close']},document.getElementById('btn-bt-conn'))
+            //  btn.innerHTML = aLangKeys[lang]['button_ok']
+          }
           }
         }
 
@@ -610,27 +636,30 @@ function run_Sattelanalyse() {
           let a = document.getElementsByClassName('imgGal2')[fi-1];
           sda_frame3 = `${host}/sattelbild?image=sda_int3&rnd=${(new Date).getTime()}`;
           img.src=sda_frame3
-          a.setAttribute('onclick',`sattelanalyse.send('recording retrieve ${recID[fi-1]} ${load_num}')`)
+          a.setAttribute('onclick',`getImgData(${fi-1},this)`)
+          gal[fi-1]=JSON.stringify(galerie_image_info)
+          //a.setAttribute('onclick',`sattelanalyse.send('recording retrieve ${recID[fi-1]} ${load_num}')`)
           if(galerie_image_info.pelvisrotation)
             pel = `${galerie_image_info.pelvisrotation.width||""}:${galerie_image_info.pelvisrotation.height||""}`
           else
             pel ="-"
-         document.getElementsByClassName('info_img')[fi-1].innerHTML =`
-         <ul class="uk-list uk-list-collapse">
-         <li key="pro_satteldruck_veloscore">Veloscore</li>
-         <li key="pro_satteldruck_becken">Rotation</li>
-         <li key="pro_satteldruck_leftright">Lins/Rechts</li>
-         <li key="pro_satteldruck_frontback">Vorn/Hinten</li>
-         </ul>
-         <ul class="uk-list uk-list-collapse">
-         <li>${galerie_image_info.veloscore}</li>
-         <li>${pel}</li>
-         <li>${galerie_image_info.left_right}</li>
-         <li>${galerie_image_info.front_rear}</li>
-         </ul>`
+          document.getElementsByClassName('info_img')[fi-1].innerHTML =`
+          <ul class="uk-list uk-list-collapse">
+          <li key="pro_satteldruck_veloscore">Veloscore</li>
+          <li key="pro_satteldruck_becken">Rotation</li>
+          <li key="pro_satteldruck_leftright">Lins/Rechts</li>
+          <li key="pro_satteldruck_frontback">Vorn/Hinten</li>
+          </ul>
+          <ul class="uk-list uk-list-collapse">
+          <li>${galerie_image_info.veloscore}</li>
+          <li>${pel}</li>
+          <li>${galerie_image_info.left_right}</li>
+          <li>${galerie_image_info.front_rear}</li>
+          </ul>
+          <textarea readonly class="uk-textarea" style="width:150px;height: 60px;margin-left:30px ">${galerie_image_info.notes}</textarea>`
          document.getElementsByClassName('name_img')[fi-1].innerHTML=`
-         <h2 class="uk-text-center">${galerie_image_info.product_label||"(no name)"}</h2>
-         <p class="uk-text-center"><small>${galerie_image_info.product||"(no name)"}</small></p>`
+         <h2 class="uk-text-center">${galerie_image_info.product_label||aLangKeys[lang]['sda_marke']}</h2>
+         <p class="uk-text-center"><small>${galerie_image_info.product||aLangKeys[lang]['sda_typ']}</small></p>`
           /* Sending a message to the sattelanalyse object. */
           if(recID[fi]){
               // console.log('sda_init3 send');
@@ -668,13 +697,16 @@ function run_Sattelanalyse() {
               let li = newElement({element:'li'},append)
               let a = newElement({element:'a',cls:['font-12'],attr:[['onclick','toProtokol()'],['key','pro_protokoll']]},li)
               a.innerHTML = '<!--Protokoll-->'
+              let li2 = newElement({element:'li'},append)
+              let a2 = newElement({element:'a',cls:['font-12'],attr:[['onclick','toGalerie()'],['key','pro_galerie']]},li2)
+              a2.innerHTML = '<!--Galerie-->'
               translatejs();
               bread++
              }
         }
        /* Checking the state of the tty. */
         if (data.wsevent === "ttystate"){
-            ttystate_check(data)
+            ttystate_check(data)  
         }
        /* Reloading the page when the tty changes. */
         if(data.wsevent === "ttychange"){
@@ -745,26 +777,26 @@ function removeArr(arr) {
 }
 
 
-/**
- * If the state is active and the driver is ttyACM0, then show the modal-tty_smartCover_ok modal.
- * Otherwise, show the modal-tty_smartCover_off modal and hide the card_A card
- * @param jsn - the JSON object returned from the server
- */
+///**
+// * If the state is active and the driver is ttyACM0, then show the modal-tty_smartCover_ok modal.
+// * Otherwise, show the modal-tty_smartCover_off modal and hide the card_A card
+// * @param jsn - the JSON object returned from the server
+// */
 function ttystate_check(jsn) {
-  // state, driver
-  let ele = document.getElementById("bolt");
-  let ele2= document.getElementById('link_bolt')
+//  // state, driver
+//  let ele = document.getElementById("bolt");
+//  let ele2= document.getElementById('link_bolt')
 
-  if (jsn.state === "active" && jsn.driver === "ttyACM0") {
-    ele.classList.remove('mdi-circle-outline')
-    ele.classList.add('mdi-link-variant')
-    ele.style.color="var(--primary-light)";
-    cable = true;
+ if (jsn.state === "active" && jsn.driver === "ttyACM0") {
+//    ele.classList.remove('mdi-circle-outline')
+//    ele.classList.add('mdi-link-variant')
+//    ele.style.color="var(--primary-light)";
+      cable = true;
   } else {
-    ele.classList.remove('mdi-circle-outline')
-    ele.classList.add('mdi-link-variant-off')
-    ele2.setAttribute('onclick','UIkit.modal($("#modal-connect-with-bluetooth")).show()')
-    ele.style.color="red";
+//    ele.classList.remove('mdi-circle-outline')
+//    ele.classList.add('mdi-link-variant-off')
+//    ele2.setAttribute('onclick','UIkit.modal($("#modal-connect-with-bluetooth")).show()')
+//    ele.style.color="red";
   }
 }
 
@@ -773,56 +805,61 @@ function ttystate_check(jsn) {
  */
 function con_bluetooth() {
   let con = setInterval(function () {
-    UIkit.modal($("#modal-connect-bluetooth")).show();
+    //UIkit.modal($("#modal-connect-bluetooth")).show();
+    connectingBt()
     sattelanalyse.send(`btconnect`);
     console.log('btconnect');
     clearInterval(con);
   }, 100);
 }
 
+function connectingBt() {
+  OpenModDialog({type:'neutral',title:["sda_blue_con_gedult"],msg:["bt_verbindung_text"]})
+}
+
 /**
  * It takes a JSON object and displays it in a modal
  * @param jsn - The JSON object that is returned from the server.
  */
 function error_msg (jsn){
   console.log("Error Message: ",jsn);  
-  let h2 = document.getElementById('error_h2');
-  let ico = document.getElementById('err_icon');
-  let txt = document.getElementById('error_p');
-  let txt_num = document.getElementById('err_number')
+  let txt = "";
+  let txt_num = "";
 
-  //h2.innerHTML = `${jsn.class} - ERROR`;
-  
-  if(jsn.class == 'user'){
-    ico.setAttribute('uk-icon','icon: warning; ratio: 1')
-  }
-  if(jsn.class == 'client'){
-    ico.setAttribute('uk-icon','icon: desktop; ratio: 1')
-  }
-  if(jsn.class == 'internal'){
-    ico.setAttribute('uk-icon','icon: server; ratio: 1')
-  }
   if(jsn.class == 'fail'){
-    ico.setAttribute('uk-icon','icon: warning; ratio: 1')
-    txt_num.setAttribute('key','err_bt_fail');
+    txt_num = 'err_bt_fail';
   }
 
-  txt.innerHTML = `MESSAGE: ${jsn.msg} `;
+  if(jsn.wsevent){
+    txt += `<p>WSEVENT: ${jsn.wsevent}</p>`
+  }
+
+  if(jsn.class){
+    txt += `<p>CLASS: ${jsn.class}</p>`
+  }
+
+  if (jsn.msg) {
+    txt += `<p>MESSAGE: ${jsn.msg}</p>`;
+  }
   
   if(jsn.source){
-    txt.innerHTML += `SOURCE: ${jsn.source} `
+    txt += `<p>SOURCE: ${jsn.source}</p>`
   }
   if(jsn.nr){
-    txt.innerHTML += `ERROR-CODE: ${jsn.nr} `
+    txt += `<p>ERROR-CODE: ${jsn.nr}</p>`
   }
   if(jsn.nr == 3){
-    txt_num.setAttribute('key','err_num_3');
+    txt_num = 'err_num_3';
+    OpenModDialog({type:'warn',title:[txt_num],msg:txt,master_btn:['button_ok']})
   }
   if(jsn.nr == 1){
-    txt_num.setAttribute('key','err_num_1');
+    txt_num ='err_num_1';
+    OpenModDialog({type:'warn',title:[txt_num],msg:txt,master_btn:['button_ok']})
+  }
+  if(jsn.nr != 1 && jsn.nr != 3){
+    txt_num ='err_num_2';
+    OpenModDialog({type:'error',title:[txt_num],msg:txt,master_btn:['button_ok']})
   }
-  translatejs()
-  UIkit.modal($("#modal-mod_error")).show();
 }
 /**
  * It opens a modal window
@@ -1159,7 +1196,7 @@ function measure(canvas) {
         endx[temp],
         endy[temp]
       );
-      text = new fabric.Text("x" + count + ": " + px + " cm", {
+      text = new fabric.Text(`x${count}: ${px} cm`, {
         left: startx[temp],
         top: starty[temp],
         stroke: setting.text_color,
@@ -1270,13 +1307,13 @@ function grid_socet(type){
   sattelanalyse.send(`set jpeg 1 grid ${type}`);
   sattelanalyse.send(`set jpeg 2 grid ${type}`);
   if(jsn_result1.wsevent){
-    let inter = setInterval(function () {
+    let inter = setInterval(() => {
       result_1(jsn_result1)
       clearInterval(inter);
     }, 100);
    }
    if(jsn_result2.wsevent){
-    let inter = setInterval(function () {
+    let inter = setInterval(() => {
       result_2(jsn_result2)
       clearInterval(inter);
     }, 100);
@@ -1321,44 +1358,62 @@ function result1(x, y,z,canvas) {
   });
   if(z.pelvisrotation)
   var c = [
-    {
-		x: z.pelvisrotation.c1.x*mult, y: ch - z.pelvisrotation.c1.y * mult
-	  },
+    //{
+		//x: z.pelvisrotation.c1.x*mult, y: ch - z.pelvisrotation.c1.y * mult
+	  //},
      {
      x:z.pelvisrotation.front.x*mult,y:ch - z.pelvisrotation.front.y*mult
      },
-    {
-		x: z.pelvisrotation.c2.x*mult, y: ch - z.pelvisrotation.c2.y * mult
-	  },
+    //{
+		//x: z.pelvisrotation.c2.x*mult, y: ch - z.pelvisrotation.c2.y * mult
+	  //},
      {
      x:z.pelvisrotation.right.x*mult,y:ch-z.pelvisrotation.right.y*mult
      },
-    {
-    x: z.pelvisrotation.c3.x*mult, y: ch - z.pelvisrotation.c3.y * mult
-	  },
+    //{
+    //x: z.pelvisrotation.c3.x*mult, y: ch - z.pelvisrotation.c3.y * mult
+	  //},
      {
      x:z.pelvisrotation.rear.x*mult,y:ch-z.pelvisrotation.rear.y*mult
      },
-    {
-    x: z.pelvisrotation.c4.x*mult, y: ch - z.pelvisrotation.c4.y * mult
-	  },
+    //{
+    //x: z.pelvisrotation.c4.x*mult, y: ch - z.pelvisrotation.c4.y * mult
+	  //},
      {
      x:z.pelvisrotation.left.x*mult,y:ch-z.pelvisrotation.left.y*mult
      },
-    {
-      x: z.pelvisrotation.c1.x*mult, y: ch - z.pelvisrotation.c1.y * mult
-      },
+    //{
+    //  x: z.pelvisrotation.c1.x*mult, y: ch - z.pelvisrotation.c1.y * mult
+    //  },
 ]
+
+//var Pelv_size = {width:(z.pelvisrotation.width*mult),height:(z.pelvisrotation.height*mult)}
+//console.log(c,z.pelvisrotation);
+
 if(z.pelvisrotation)
-	var polygon = new fabric.Polygon(c, {
-		strokeWidth: 1,
-    stroke: setting.pr_color,
-    fill:'rgba(0,0,0,0)',
-		scaleX: setting.pelv,
-		scaleY: setting.pelv,
-    selectable: false,
-    selection: false
-	});
+var polygon = new fabric.Rect({
+  left: x1 - ((z.pelvisrotation.width)*setting.pelv)/2,
+  top: x2 - ((z.pelvisrotation.height)*setting.pelv)/2,
+  fill: 'rgba(255,255,255,0.3)',
+  selectable: false,
+  selection: false,
+  stroke:setting.pr_color,
+  width: (z.pelvisrotation.width)*setting.pelv,
+  height: (z.pelvisrotation.height)*setting.pelv
+});
+
+	//var polygon = new fabric.Polygon(c, {
+	//	strokeWidth: 1,
+  //  stroke: setting.pr_color,
+  //  fill:'rgba(0,0,0,0)',
+	//	//scaleX: setting.pelv,
+	//	//scaleY: setting.pelv,
+  //  left:x1,
+  //  top:x2,
+  //  selectable: false,
+  //  selection: false
+	//});
+
   //center of Presure
   var kreis = new fabric.Circle({
     left: x1 - 10,
@@ -1397,19 +1452,123 @@ if(z.pelvisrotation)
   canvas.renderAll();
 }
 
+$('#product1')[0].addEventListener('input', function (evt) {
+  console.log(this.value);
+  if(localStorage.getItem('product1')){
+    let pro1 = JSON.parse(localStorage.getItem('product1'))
+    pro1.product = this.value
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  } else {
+    let pro1 = {}
+    pro1.product = this.value
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  }
+});
+$('#product_label1')[0].addEventListener('input', function (evt) {
+  console.log(this.value);
+  if(localStorage.getItem('product1')){
+    let pro1 = JSON.parse(localStorage.getItem('product1'))
+    pro1.label = this.value
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  } else {
+    let pro1 = {}
+    pro1.label = this.value
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  }
+});
+$('#notes1')[0].addEventListener('input', function (evt) {
+  console.log(this.value);
+  if(localStorage.getItem('product1')){
+    let pro1 = JSON.parse(localStorage.getItem('product1'))
+    pro1.note = this.value
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  } else {
+    let pro1 = {}
+    pro1.note = this.value
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  }
+});
+$('#product2')[0].addEventListener('input', function (evt) {
+  console.log(this.value);
+  if(localStorage.getItem('product2')){
+    let pro1 = JSON.parse(localStorage.getItem('product2'))
+    pro1.product = this.value
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  } else {
+    let pro1 = {}
+    pro1.product = this.value
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  }
+});
+$('#product_label2')[0].addEventListener('input', function (evt) {
+  console.log(this.value);
+  if(localStorage.getItem('product2')){
+    let pro1 = JSON.parse(localStorage.getItem('product2'))
+    pro1.label = this.value
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  } else {
+    let pro1 = {}
+    pro1.label = this.value
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  }
+});
+$('#notes2')[0].addEventListener('input', function (evt) {
+  console.log(this.value);
+  if(localStorage.getItem('product2')){
+    let pro1 = JSON.parse(localStorage.getItem('product2'))
+    pro1.note = this.value
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  } else {
+    let pro1 = {}
+    pro1.note = this.value
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  }
+});
 
+var product1 = new Object();
+var product2 = new Object();
+
+product1 = localStorage.getItem('product1') ? JSON.parse(localStorage.getItem('product1')) : {"product":"","label":"","note":""};
+product2 = localStorage.getItem('product2') ? JSON.parse(localStorage.getItem('product1')) : {"product":"","label":"","note":""};
+
+function clearProduct(num){
+  localStorage.removeItem(`product${num}`)
+  $(`#product${num}`)[0].value = '';
+  $(`#product_label${num}`)[0].value = '';
+  $(`#notes${num}`)[0].value = '';
+}
 /**
  * The function takes the JSON object returned from the API and displays the results on the page
  * @param jsn - the JSON object returned from the API
  */
 function result_1(jsn) {
-  // console.log(jsn);
+  console.log('result1',jsn);
+
+  if(jsn.product === ""){
+    setProduct1({pro:" "})
+  } else {
+    setProduct1({pro:jsn.product})
+  }
+
+  if(jsn.product_label === ""){
+    setProduct1({label:" "})
+  } else {
+    setProduct1({label:jsn.product_label})
+  }
+
+  if(jsn.notes === "") {
+    setProduct1({note:" "})
+  } else {
+    setProduct1({note:jsn.notes})
+  }
+
+
   $("#res1_veloscore")[0].innerHTML = jsn.veloscore||'';
   $("#res1_front_rear")[0].innerHTML = jsn.front_rear||'';
   $("#res1_left_right")[0].innerHTML = jsn.left_right||'';
-  $('#product1')[0].value = jsn.product||'';
-  $('#product_label1')[0].value =jsn.product_label||'';
-  $('#notes1')[0].value = jsn.notes||'';
+  //$('#product1')[0].value = pro.product;
+  //$('#product_label1')[0].value =pro.label;
+  //$('#notes1')[0].value = pro.note;
   if(jsn.pelvisrotation){
   $("#res1_rotation")[0].innerHTML =
   jsn.pelvisrotation.width + ":" + jsn.pelvisrotation.height||'';
@@ -1432,13 +1591,33 @@ function result_1(jsn) {
  * @param jsn - the JSON object returned from the API
  */
 function result_2(jsn) {
-  // console.log(jsn);
+  console.log('result2',jsn);
+
+  if(jsn.product === ""){
+    setProduct2({pro:" "})
+  } else {
+    setProduct2({pro:jsn.product})
+  }
+
+  if(jsn.product_label === ""){
+    setProduct2({label:" "})
+  } else {
+    setProduct2({label:jsn.product_label})
+  }
+
+  if(jsn.notes === "") {
+    setProduct2({note:" "})
+  } else {
+    setProduct2({note:jsn.notes})
+  }
+
+
   $("#res2_veloscore")[0].innerHTML = jsn.veloscore;
   $("#res2_front_rear")[0].innerHTML = jsn.front_rear;
   $("#res2_left_right")[0].innerHTML = jsn.left_right;
-  $('#product2')[0].value = jsn.product||'';
-  $('#product_label2')[0].value =jsn.product_label||'';
-  $('#notes2')[0].value = jsn.notes||'';
+  //$('#product2')[0].value = pro.product;
+  //$('#product_label2')[0].value = pro.label;
+  //$('#notes2')[0].value = pro.note;
   if(jsn.pelvisrotation){
   $("#res2_rotation")[0].innerHTML =
   jsn.pelvisrotation.width + ":" + jsn.pelvisrotation.height;
@@ -1481,14 +1660,37 @@ function toProtokol() {
   location.pathname = '/production/protokoll.tcls';
 }
 
-/**
- * It opens the modal window with the ID "modal-einstellungen" when the button with the ID "config" is
- * clicked
- */
-function config() {
-  UIkit.modal('#modal-einstellungen').show();
+function toGalerie() {
+  if(localStorage.getItem('session').split(' ')[0]=='restart'){
+    sess = localStorage.getItem('session').split(' ')[1]
+  }
+  if(localStorage.getItem('session').split(' ')[0]=='start'){
+     onsqlresult = getSession
+     sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
+  }
+  let info = new Object();
+  info.product = $(`#product1`)[0].value;
+  info.product_label = $(`#product_label1`)[0].value;
+  info.notes = $(`#notes1`)[0].value;
+  // console.log(`recording store 1 ${JSON.stringify(info)}`);
+  sattelanalyse.send(`recording store 1 ${JSON.stringify(info)}`);
+  info.product = $(`#product2`)[0].value;
+  info.product_label = $(`#product_label2`)[0].value;
+  info.notes = $(`#notes2`)[0].value;
+  // console.log(`recording store 2 ${JSON.stringify(info)}`);
+  sattelanalyse.send(`recording store 2 ${JSON.stringify(info)}`);
+  sattelanalyse.send(`sql UPDATE sessions SET notes='${document.getElementById('note_session').value||""}' WHERE session_id=${sess}`)
+  location.pathname = '/production/galerie.tcls';
 }
 
+///**
+// * It opens the modal window with the ID "modal-einstellungen" when the button with the ID "config" is
+// * clicked
+// */
+//function config() {
+//  UIkit.modal('#modal-einstellungen').show();
+//}
+
 /**
  * It takes a parameter, and logs it to the console
  * @param params - {
@@ -1512,24 +1714,11 @@ function RowImg(params) {
   fi = 0;
   recID = [];
   onsqlresult = getLog;
-  // var live = document.getElementById('live');
-  // live.classList.add('hidden')
   var append1 = document.getElementById('img_list')//('img_gal')
-  // append1.classList.remove('hidden_imglist')
-  append1.classList.add('uk-padding')
-  append1.setAttribute('style','width: 92vw')
   append1.innerHTML ="";
-  var close = document.createElement('button')
-  close.setAttribute('onclick','exitImgList()')
-  close.setAttribute('style','height: 3em;width: 3em;right: 2em;')
-  close.classList.add('uk-button','close','uk-position-right')
-  close.innerHTML = "X"
-  append1.append(close)
   params.forEach(element => {
       // console.log(element);
-      let res = JSON.parse(element.results)
           if(fi===0){
-              // console.log('RowImg send');
               sattelanalyse.send(`recording retrieve ${element.recording_id} 3`)
               fi++
           }
@@ -1547,14 +1736,15 @@ function RowImg(params) {
           // a.append(velosore)
           // append1.append(a)
           let master = document.createElement('div');
-            master.classList.add('hover','imgGal2');
-            master.id = `img_${element.recording_id}`
-            // master.setAttribute('onclick','selectImg(this)')
-            append1.append(master);
+          master.classList.add('imgGal2'); //hover
+          master.id = `img_${element.recording_id}`
+          //  // master.setAttribute('onclick','selectImg(this)')
+          append1.append(master);
 
             let div = document.createElement('div');
             div.classList.add('flex-column-center')
-            div.setAttribute('style','border:1px solid green;padding:5px; width:200px;margin:0 10px 0 0;');
+            div.id = `sel_${element.recording_id}`
+          //  div.setAttribute('style','border:1px solid green;padding:5px; width:200px;margin:0 10px 0 0;');
             master.append(div);
 
             let date = document.createElement('p');
@@ -1570,23 +1760,58 @@ function RowImg(params) {
             // a.classList.add('imgGal2')
 
             let img = document.createElement('img');
-            img.width=150;
+            img.width=100;
             img.height=100;
             img.classList.add('imgGal1');
             div.append(img);
 
             let div2 = document.createElement('div')
-            div2.setAttribute('style','width: 200px')
+            div2.setAttribute('style','width: 150px')
             div.append(div2)
 
             let div_info = document.createElement('div');
-            div_info.classList.add('uk-grid','uk-child-width-1-2','info_img');
+            div_info.classList.add('uk-grid','uk-child-width-1-2','info_img','detail','hidden');
+            let chk = document.getElementById('check_img_detail');
+            if(chk.checked){
+              div_info.classList.remove('hidden')
+            }
             div_info.setAttribute('style','margin: 0 -30px;');
             div2.append(div_info);
   });
+  UIkit.modal($("#modal-mod_imgList")).show();
 
 }
 
+function getImgData(num,ele) {
+  galerie_image_info = JSON.parse(gal[num])
+  //console.log(galerie_image_info);
+  console.log();
+
+  let noselect = document.getElementsByClassName('flex-column-center')
+  for (const iterator of noselect) {
+    iterator.removeAttribute('style')
+  }
+  ele.firstChild.setAttribute('style','border: 1px solid var(--primary);padding: 0.5em')
+
+   let btn = document.getElementById('img_select_btn');
+   btn.setAttribute('onclick',`sattelanalyse.send('recording retrieve ${recID[num]} ${load_num}')`)
+   btn.removeAttribute("disabled")
+  translatejs()
+}
+
+check_img_detail.addEventListener('change', function() {
+  let detail = document.getElementsByClassName('detail')
+  if (this.checked) {
+    for (const iterator of detail) {
+      iterator.classList.remove('hidden')
+    }
+  } else {
+    for (const iterator of detail) {
+      iterator.classList.add('hidden')
+    }
+  }
+});
+
 /**
  * The function is called when the user clicks on the "Exit" button. The function removes the "hidden"
  * class from the "live" div and adds the "hidden" class to the "img_list" div
@@ -1623,11 +1848,119 @@ $('document').ready(()=>{
       comp[0].setAttribute('style','background-color: var(--primary);border-color: var(--primary);box-shadow: var(--primary) 0px 0px 0px 11px inset;transition: border 0.4s ease 0s, box-shadow 0.4s ease 0s, background-color 1.2s ease 0s;')
 });
 
-function showErrormessage() {
-    let x = document.getElementById("error_p");
-    if (x.style.display === "none") {
-        x.style.display = "block";
-    } else {
-        x.style.display = "none";
+/**
+ * `ClientInfo` is a function that takes a single parameter, `params`, and stores it in local storage
+ * @param params - {
+ */
+function ClientInfo(params) {
+  onsqlresult = getLog;
+  localStorage.setItem('client_info',JSON.stringify(params));
+}
+/**
+ * It takes three arguments, sends a query to the database, and then creates a table with the results
+ * of the query
+ * @param {number}client_id - The client's ID
+ * @param {string}name - The name of the client
+ * @param {string}mail - The email address of the user.
+ */
+function info(client_id,name,mail,fc) {
+  onsqlresult = ClientInfo
+  sattelanalyse.send(`sql select * from sessions where client_id=${client_id}`);
+  let inter = setInterval(()=> {
+      localStorage.setItem('client_fc',fc)
+      localStorage.setItem('client_name',name)
+      localStorage.setItem('client_mail',mail)
+      localStorage.setItem('client_id',client_id)
+
+      location.href = "/production/client.tcls"
+
+      clearInterval(inter);
+    }, 500);
+
+}
+
+/**
+ * The function updates and stores product and label values in local storage based on user input.
+ * @param {number}params - A parameter that determines which product field to update (either 1 or 2).
+ * @param {HTMLBaseElement}x - The "x" parameter is a reference to the HTML element that triggered the function.
+ * @param {number}field - The field parameter is used to determine whether the value being passed should be
+ * assigned to the "product" or "label" field in the local storage object. If field is equal to 1, the
+ * value is assigned to the "product" field, otherwise it is assigned to the "label" field
+ */
+function TextTo(params,x,field) {
+  let pro1;
+  if(params==1){
+    if(field==1){
+      document.getElementById('product1').value = x.nextElementSibling.value
+      pro1 = localStorage.getItem('product1') ? JSON.parse(localStorage.getItem('product1')) : {};
+      pro1.product = x.nextElementSibling.value
+    } else{
+      document.getElementById('product_label1').value = x.nextElementSibling.value
+      pro1 = localStorage.getItem('product1') ? JSON.parse(localStorage.getItem('product1')) : {};
+      pro1.label = x.nextElementSibling.value
     }
-} 
\ No newline at end of file
+    localStorage.setItem('product1',JSON.stringify(pro1))
+  } else {
+    if(field==1){
+      document.getElementById('product2').value = x.nextElementSibling.value
+      pro1 = localStorage.getItem('product2') ? JSON.parse(localStorage.getItem('product2')) : {};
+      pro1.product = x.nextElementSibling.value
+    } else{
+      document.getElementById('product_label2').value = x.nextElementSibling.value
+      pro1 = localStorage.getItem('product2') ? JSON.parse(localStorage.getItem('product2')) : {};
+      pro1.label = x.nextElementSibling.value
+    }
+    localStorage.setItem('product2',JSON.stringify(pro1))
+  }
+}
+
+function setProduct1(params) {
+  let pro = document.getElementById('product1')
+  let label = document.getElementById('product_label1')
+  let note = document.getElementById('notes1')
+  let local = localStorage.getItem('product1') ? JSON.parse(localStorage.getItem('product1')) : {product:"",label:"",note:""}
+
+  if(params.pro){
+    pro.value = params.pro
+    local.product = params.pro
+  }
+
+  if(params.label){
+    label.value = params.label
+    local.label = params.label
+  }
+
+  if(params.note){
+    note.value = params.note
+    local.note = params.note
+  }
+  localStorage.setItem('product1',JSON.stringify(local))
+}
+
+/**
+ * The function sets the values of product, label, and notes for a specific element with the ID
+ * "product2".
+ * @param params - The `params` parameter is an object that contains the following properties:
+ */
+function setProduct2(params) {
+  let pro = document.getElementById('product2')
+  let label = document.getElementById('product_label2')
+  let note = document.getElementById('notes2')
+  let local = localStorage.getItem('product2') ? JSON.parse(localStorage.getItem('product2')) : {product:"",label:"",note:""}
+  
+  if(params.pro){
+    pro.value = params.pro
+    local.product = params.pro
+  }
+
+  if(params.label){
+    label.value = params.label
+    local.label = params.label
+  }
+
+  if(params.note){
+    note.value = params.note
+    local.note = params.note
+  }
+  localStorage.setItem('product2',JSON.stringify(local))
+}
