@@ -30,6 +30,8 @@ var log = localStorage.getItem('log') || false;
 var week = ["week_0","week_1","week_2","week_3","week_4","week_5","week_6"];
 var month = ["mon_0","mon_1","mon_2","mon_3","mon_4","mon_5","mon_6","mon_7","mon_8","mon_9","mon_10","mon_11"];
 
+var httpSetconfig = new XMLHttpRequest();
+var httpreboot = new XMLHttpRequest();
 
 
 var devLangKeys = new Object();
@@ -79,6 +81,7 @@ back.classList.add(`img_0`)
   lang_list.append(li)
   // lang_list_2.append(div)
   });
+/* The above code is used to change the placeholder of the input fields. */
   for(const key3 in document.querySelectorAll('[key-place]')){
     const element3 = document.querySelectorAll('[key-place]')[key3];
       if(element3.tagName){
@@ -93,6 +96,8 @@ back.classList.add(`img_0`)
       }
 
   }
+  /* The above code is setting the title attribute of the element with the key-title attribute to the
+  value of the key in the params object. */
   for(const key2 in document.querySelectorAll('[key-title]')){
     const element2 = document.querySelectorAll('[key-title]')[key2];
       if(element2.tagName){
@@ -106,6 +111,7 @@ back.classList.add(`img_0`)
       localStorage.setItem('devLang',JSON.stringify(devLangKeys))
       }
   }
+/* Adding a class to the element and then creating a modal for the element. */
   for(const key4 in document.querySelectorAll('[key-readme]')){
     const readmeElement = document.querySelectorAll('[key-readme]')[key4];
     // console.log('ReadmeElement:',readmeElement);
@@ -116,6 +122,8 @@ back.classList.add(`img_0`)
       readmeElement.setAttribute('onclick',`OpenReadMe('${varRead}')`) //Z 634
     }
   }
+/* Looping through all the elements with the attribute key and replacing the innerHTML with the value
+of the key in the params object. */
   for (const key in document.querySelectorAll('[key]')) {
     const element = document.querySelectorAll('[key]')[key];
     if(element.innerHTML){
@@ -133,7 +141,7 @@ back.classList.add(`img_0`)
 
 /**
  * It sets the language to the local storage and then fetches the json file and translates the page.
- * @param lang - The language you want to translate to.
+ * @param {String}lang - The language you want to translate to.
  */
 function langSelected(lang) {
   let httplang = new XMLHttpRequest();
@@ -164,66 +172,26 @@ function translatejs() {
   } catch (error) {
     console.log(error);
   }
-
-
 }
 
 $(document).ready(function () {
   translatejs();
-  // lang = localStorage.getItem('lang')||null;
-  // // console.log(localStorage);
-  // if (lang == null) {
-  //   if (
-  //     navigator.language.includes('de')||
-  //     navigator.language.includes('en')||
-  //     navigator.language.includes('es')||
-  //     navigator.language.includes('pt')
-  //   ) {
-  //     lang = navigator.language.split('-')[0];
-  //     localStorage.setItem('lang',lang)
-  //     $("#sprachwahl").attr("src", `images/${lang}.png`);
-  //     console.log(`Sprache auf "${lang}" gesetzt`);
-  //   } else {
-  //     lang = "en";
-  //     localStorage.setItem('lang',lang)
-  //     $("#sprachwahl").attr("src", `images/${lang}.png`);
-
-  //     console.log(`Browsersprache konnte nicht ermittelt werden und wurde auf ${lang} gesetzt`);
-  //   }
-  // } else {
-  //   console.log("Sprache: " + lang);
-  //   $("#sprachwahl").attr("src", `images/${lang}.png`);
-  //   fetch("/production/localisation/lang.json", {
-  //     mode: "no-cors",
-  //   }) // disable CORS because path does not contain http(s)
-  //     .then((res) => res.json())
-  //     .then((data) => (_Translate(data)));
-  // }
   localstart();
 });
 
-// Fullscreen
-/* A JavaScript function that is executed when the user clicks on a language button. */
-$(document).ready(function () {
-  $(".fullscreen_button").on("click", function () {
-    (document.fullScreenElement && null !== document.fullScreenElement) ||
-    (!document.mozFullScreen && !document.webkitIsFullScreen)
-      ? document.documentElement.requestFullScreen
-        ? document.documentElement.requestFullScreen()
-        : document.documentElement.mozRequestFullScreen
-        ? document.documentElement.mozRequestFullScreen()
-        : document.documentElement.webkitRequestFullScreen &&
-          document.documentElement.webkitRequestFullScreen(
-            Element.ALLOW_KEYBOARD_INPUT
-          )
-      : document.cancelFullScreen
-      ? document.cancelFullScreen()
-      : document.mozCancelFullScreen
-      ? document.mozCancelFullScreen()
-      : document.webkitCancelFullScreen && document.webkitCancelFullScreen();
-  });
-});
+function reinit() {
+  var url = "/production/reinit.tcls";
 
+  localStorage.removeItem('smartcube')
+
+  httpreboot.open("GET", url, true);
+  httpreboot.send();
+
+  let inter = setInterval(()=> {
+    window.location.reload(true);
+      clearInterval(inter);
+    }, 1000);
+} // reinit()
 /**
  * The function starts a countdown and then reboots the Velobox
  */
@@ -254,13 +222,7 @@ function countdown() {
   var seconds = 50;
   var progress = document.getElementById('progress_restart')
   function tick() {
-    // var counter = document.getElementById("counter");
     seconds--;
-    // counter.innerHTML =
-    //   '<span class="tr" key="global_einsatzbereit"><!--Die Velobox ist wieder einsatzbereit in nur--></span> <b>0:' +
-    //   (seconds < 10 ? "0" : "") +
-    //   String(seconds) +
-    //   '</b> <span class="tr" key="global_minuten"><!--Minuten--></span>';
       progress.value +=1
     if (seconds > 0) {
       setTimeout(tick, 1000);
@@ -309,8 +271,12 @@ function BreadCrumb(params) {
         // li.classList.add('hidden')
         //}
         if(element==='client'){
+          let a2 = newElement({element:'a',attr:[['href',`/production/${element}.tcls`],['style','display:none;']]},li)
           a.removeAttribute('key');
           a.innerHTML = localStorage.getItem('client_name')
+          a.setAttribute('href','#')
+          a.setAttribute('onclick',`info(${localStorage.getItem('client_id')},'${localStorage.getItem('client_name')}','${localStorage.getItem('client_mail')||""}','${localStorage.getItem('client_fc')}')`)
+          //info(`${localStorage.getItem('client_id')}`,`${localStorage.getItem('client_name')}`,`${localStorage.getItem('client_mail')||""}`,`${localStorage.getItem('client_fc')}`)
           s.removeAttribute('key');
           s.innerHTML = localStorage.getItem('client_name')
         }
@@ -334,12 +300,9 @@ function HelpReset() {
  * @param sprache - The language of the handbook.
  */
  function setHandbuchfile(sprache) {
-
   var url = "/production/korrekturhandbuch.tcls?sprache=" + sprache;
-
   httpSetconfig.open("GET", url, true);
   httpSetconfig.send();
-
 }
 
 /**
@@ -351,6 +314,19 @@ function LinkTo(params) {
   location.href = `/production/${params}`
 }
 
+/**
+ * The function "PrintLog" logs a message to the console if the "log" variable is true.
+ * @param {Array<String>}params - The parameter "params" is a variable that represents the data or message that needs
+ * to be logged. It is passed as an argument to the function "PrintLog".
+ */
+function PrintLog(params) {
+  if (log) {
+    params.forEach(element => {
+      console.log(element);
+    });
+  }
+}
+
 /**
 * It checks if the user has already seen the first start modal and if not, it shows it
 */
@@ -401,7 +377,10 @@ if(location.pathname == "/production/new_satteldruckanalyse.tcls"){
   BreadCrumb(['dashboard','clients','client','new_satteldruckanalyse']);
 }
 if(location.pathname == "/production/protokoll.tcls"){
-  BreadCrumb(['dashboard','clients','client','protokoll'])
+  BreadCrumb(['dashboard','clients','client','protokoll','galerie'])
+}
+if(location.pathname == "/production/galerie.tcls"){
+  BreadCrumb(['dashboard','clients','client','protokoll','galerie'])
 }
 if(location.pathname == "/production/handbuch.tcls"){
   BreadCrumb(['dashboard','handbuch'])
@@ -585,6 +564,11 @@ let m_men = document.getElementsByClassName('men');
   }
 })
 
+/**
+ * It takes a string, and returns a translated string
+ * @param {String}params - The string you want to translate.
+ * @returns The value of the key in the object.
+ */
 function gettrans(params) {
   lang = localStorage.getItem('lang')
   console.log(params,lang);
@@ -597,6 +581,10 @@ function gettrans(params) {
   }
 }
 
+/**
+ * It sets the position of the element with the id of "foo" to fixed, and sets the width and height of
+ * the element to the width and height of the window
+ */
 function abso() {
 ch = $(window).height();
 cw = $(window).width()/1.25;
@@ -612,6 +600,8 @@ cw = $(window).width()/1.25;
       left: '10%'
   });
 }
+
+
 try {
 let side_smartcube = document.getElementById('sitzknochen-menu');
 if(localStorage.getItem('hocker')=="on"){
@@ -626,6 +616,7 @@ if(localStorage.getItem('hocker')=="on"){
 }
 
 
+/* A clock. */
 let clock_dash = setInterval(function () {
   let c = document.getElementById('clock');
   let time = new Date();
@@ -676,6 +667,11 @@ function newElement(jsn, DOM_Element) {
 }
 
 // MODAL README
+/**
+ * It creates a modal window with a button to close it, and then fetches the HTML file from the server
+ * and inserts it into the modal window
+ * @param {String}params - the name of the file to be loaded.
+ */
 function CreateReadMeMod(params) {
   let append;
   if(document.getElementById('ModalHolder')){
@@ -698,21 +694,159 @@ function CreateReadMeMod(params) {
     .then((data) => (ModalReadmeText1.innerHTML=data));
 
   // ModalReadmeText1.innerHTML = aLangKeys[lang][`${params}__HTML`]
-
-
 }
 
-// OpenReadMe
+/**
+ * > This function opens a modal window with the id of `mod_`
+ * @param {String}params - The name of the modal you want to open.
+ */
 function OpenReadMe(params) {
   UIkit.modal(`#mod_${params}`).show();
 }
 
-if(location.pathname == '/production/sitzknochenvermessung.tcls'){
-  var menueintrag = document.getElementById('sitzknochenvermessung');
-  menueintrag.classList.add('hidden');
+/**
+ * If the error message is not displayed, display it. Otherwise, hide it
+ */
+function showErrormessage() {
+  let x = document.getElementsByClassName("error_p");
+  for (const ele of x) {
+    if (ele.style.display === "none") {
+      ele.style.display = "block";
+  } else {
+      ele.style.display = "none";
+  }
+  }
+}
+/**
+ * `window.open(url, name, specs, replace)`
+ * 
+ * The `url` is the page you want to open. The `name` is the name of the window. The `specs` are the
+ * features of the window. The `replace` is a boolean value that determines whether the URL creates a
+ * new entry or replaces the current entry in the history list
+ */
+function openWindow() {
+  window.open(`${location.origin}/production/dashboard.tcls`, "NewWindow",`toolbar=no,menubar=no,scrollbars=no,fullscreen=yes,width=${screen.width},height=${screen.height}`)
+  //this.close()
+  closeWindow()
+}
+function closeWindow() { 
+  window.open('','_parent',''); 
+  window.close(); 
 }
 
-function openWindow() {
-  window.open(`${location.origin}`, "NewWindow",`toolbar=no,menubar=no,scrollbars=no,fullscreen=yes,width=${screen.width},height=${screen.height}`)
-  this.close()
+// sample warn
+//let dialogSample = {type:'warn',title:"Sitzung #215 löschen?",msg:["cli_session_text"],master_btn:["button_delete","SelectSessionDel()"],slave_btn:["button_cancel"]}
+/**
+ * It creates a modal dialog with a header, body and footer
+ * @param {JSON.type}jsn - head:"overwrites the defautl head",title:what happend, msg:more info hidden,master_btn:[translationkey,onclick(nothing=close),slave_btn:[translationkey,onclick(nothing=close)]
+ * @type {String} -warn || error || neutral || success
+ * @head {Sring} - overwrites the head
+ * @title {String || Array} -Array:set an translate key -String: a normal string
+ * @msg {string || Array} - Array: set the translate key for more informations -String: a normal string (server messages)
+ * @master_btn {Array<String>} - ["transKey",functon()-optional] if no function default is close modal --Optional
+ * @slave_btn {Array<String>} - ["transKey",functon()-optional] if no function default is close modal --Optional
+ */
+function OpenModDialog(jsn){
+let holder;
+if(document.getElementById('ModalHolder')){
+  holder = document.getElementById('ModalHolder');
+} else {
+  holder = newElement({element:'div',id:'ModalHolder'},document.getElementsByTagName('body')[0]);
 }
+
+let modal = newElement({element:'div',attr:[['uk-modal','']]},holder)
+let dialog= newElement({element:'div',cls:['uk-modal-dialog']},modal)
+let head  = newElement({element:'div',cls:['uk-modal-header',`mod_${jsn.type}`]},dialog)
+  let title = newElement({element:'h2',cls:['uk-modal-title'],attr:[['style','color:var(--secondary-text)'],[`key`,`mod_${jsn.type}`]]},head).innerHTML = '<!--title-->'
+if(jsn.head){
+  let title = newElement({element:'h2',cls:['uk-modal-title'],attr:[['style','color:var(--secondary-text)']]},head).innerHTML = jsn.head
+}
+let X = newElement({element:'button',cls:['uk-modal-close-default'],attr:[['uk-close','']]},head)
+let body = newElement({element:'div',cls:['uk-modal-body']},dialog)
+let h4 = newElement({element:'h4',attr:[['style','color:var(--primary-text)'],['onclick','showErrormessage()']]},body)
+let h4d= newElement({element:'div',cls:['info_msg','uk-margin-bottom']},h4)
+if(jsn.type === 'warn'){
+  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-alert'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
+}
+if(jsn.type === 'error'){
+  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-minus-circle'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
+}
+if(jsn.type === 'success'){
+  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-help-circle'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
+}
+if(jsn.type === 'neutral'){
+  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-alert-circle'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
+}
+if(Array.isArray(jsn.title)){
+  let warn = newElement({element:'span',attr:[['key',jsn.title[0]]]},h4d).innerHTML = '<!--title-->'
+} else{
+  let warn = newElement({element:'span'},h4d).innerHTML = jsn.title
+
+}
+let p = newElement({element:'p',cls:['error_p'],attr:[['style','display:none']]},h4)
+if(Array.isArray(jsn.msg)){
+let span = newElement({element:'span',attr:[['key',jsn.msg]]},p).innerHTML= '<!--msg-->'
+} else {
+let span = newElement({element:'span'},p).innerHTML= jsn.msg
+}
+let foot = newElement({element:'div',cls:['uk-modal-footer','uk-text-right']},dialog)
+if(jsn.slave_btn){
+  let slave = newElement({element:'button',cls:['uk-button', 'uk-button-default', 'uk-modal-close'],attr:[['key',jsn.slave_btn[0]]]},foot)
+  if(jsn.slave_btn[1])
+  slave.setAttribute('onclick',jsn.slave_btn[1])
+  slave.innerHTML = '<!--title-->'
+}
+if (jsn.master_btn) {
+  let master = newElement({element:'button',cls:['uk-margin-left','uk-button', `uk-button-${jsn.type}`, 'uk-modal-close'],attr:[['key',jsn.master_btn[0]]]},foot)
+  if(jsn.master_btn[1])
+  master.setAttribute('onclick',jsn.master_btn[1])
+  master.innerHTML = '<!--title-->'
+}
+translatejs()
+UIkit.modal(modal).show();
+}
+
+var elem = document.documentElement;
+var fullScreen = false
+
+function Vollbild() {
+    if (fullScreen) {
+        closeFullscreen()
+        }
+    if (!fullScreen) {
+        openFullscreen()
+        }
+    }
+
+function openFullscreen() {
+    if (elem.requestFullscreen) {
+        elem.requestFullscreen();
+        } 
+    else if (elem.mozRequestFullScreen) { /* Firefox */
+        elem.mozRequestFullScreen();
+        } 
+    else if (elem.webkitRequestFullscreen) { /* Chrome, Safari & Opera */
+        elem.webkitRequestFullscreen();
+        } 
+    else if (elem.msRequestFullscreen) { /* IE/Edge */
+        elem.msRequestFullscreen();
+        }
+        fullScreen = true
+    }
+
+function closeFullscreen() {
+    if (document.exitFullscreen) {
+        document.exitFullscreen();
+        } 
+    else if (document.mozCancelFullScreen) {
+        document.mozCancelFullScreen();
+        } 
+    else if (document.webkitExitFullscreen) {
+        document.webkitExitFullscreen();
+        } 
+    else if (document.msExitFullscreen) {
+        document.msExitFullscreen();
+        }
+        fullScreen=false
+    }
+
