@@ -48,14 +48,24 @@ function getLog(params){
     console.log(params);
 }
 
-if(location.pathname === "/production/clients.tcls"){
-     let inter = setInterval(function () {
+//if(location.pathname === "/production/clients.tcls"){
+//     let inter = setInterval(function () {
+        
+//        clearInterval(inter);
+//       }, 1000);
+
+//}
+
+var galerie_image_info = {};
+
+session.addEventListener("open", (event) => {
+    if(location.pathname === "/production/clients.tcls"){
+        document.getElementById('loader').classList.add('hidden')
+        end_session()
         onsqlresult = clients_list;
         session.send(`sql select * from clients order by client_id desc`)
-        clearInterval(inter);
-       }, 1000);
-
-}
+    }
+});
 
 var galerie_image_info = {};
 
@@ -219,48 +229,13 @@ function info(client_id,name,mail,fc) {
     append1 = document.getElementById('imagelist');
     append1.innerHTML = "";
     let inter = setInterval(()=> {
-        //
-        // var head = ['Session','Datum','','']
-        // localStorage.setItem('client_info',JSON.stringify(rows));
+
         localStorage.setItem('client_fc',fc)
         localStorage.setItem('client_name',name)
         localStorage.setItem('client_mail',mail)
         localStorage.setItem('client_id',client_id)
-        // var x = JSON.parse(localStorage.getItem('client_info'));
-        // var modal = $('#modal-infos')
-        // $('#info_title')[0].innerHTML = `Sitzungshistorie: ${name}`
-        // $('#name_img')[0].innerHTML = `${name}`
-        // $('#info_body')[0].innerHTML = "";
-        // var Append = $('#info_body');
-        // var table = document.createElement('table')
-        // table.classList.add('uk-table', 'uk-table-hover', 'uk-table-divider')
-        // Append.append(table)
-        // var thead = document.createElement('thead');
-        // table.append(thead)
-        // var tr_head = document.createElement('tr');
-        // thead.append(tr_head);
-        // head.forEach(e=>{
-        //     var th_head = document.createElement('th');
-        //     th_head.innerHTML = e;
-        //     tr_head.append(th_head);
-        // })
-        // var tbody = document.createElement('tbody');
-        // table.append(tbody);
-
-        // x.forEach(e=>{
-        //     var tr_body = document.createElement('tr');
-        //     tr_body.setAttribute('uk-tooltip','Sitzung Vortsetzen')
-        //     tr_body.classList.add('cur_pointer')
-        //     // tr_body.setAttribute('onclick',`rest_session(${e.session_id})`)
-        //     tbody.append(tr_body);
-        //     tr_body.innerHTML  = `<td onclick="rest_session(${e.session_id})">${e.session_id}</td>`;
-        //     tr_body.innerHTML += `<td onclick="rest_session(${e.session_id})">${e.date}</td>`;
-        //     tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small" uk-tooltip="Bildergalerie Anzeigen" onclick="session_img(${e.session_id})" uk-icon="icon: image"></button></td>`;
-        //     tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small adba basicview" uk-tooltip="Sitzung löschen" onclick="SessionDel(${e.session_id})" uk-icon="icon: trash"></button></td>`
-        // })
         location.href = "/production/client.tcls"
-        // UIkit.modal(modal).show();
-        // ToggleViewMode(`${localStorage.getItem('viewmode')}`);
+
         clearInterval(inter);
       }, 500);
 
@@ -271,14 +246,14 @@ function info(client_id,name,mail,fc) {
  * @param params - The name of the session to be deleted
  */
 function SessionDel(params) {
-    $('#del_title')[0].innerHTML = `${aLangKeys[lang]['cli_session_del1']}${params} ${aLangKeys[lang]['cli_session_del2']}`
-    UIkit.modal('#modal_del').show();
+    let text = `${aLangKeys[lang]['cli_session_del1']}${params} ${aLangKeys[lang]['cli_session_del2']}`
+    OpenModDialog({type:'warn',title:text,msg:["cli_session_text"],master_btn:['button_delete','SelectSessionDel()'],slave_btn:['button_cancel']})
     localStorage.setItem('del_session', params)
 }
 
 function ClientDel(params) {
-    $('#del_cli_title')[0].innerHTML = `${aLangKeys[lang]['cli_client_del1']}${params} ${aLangKeys[lang]['cli_session_del2']}`
-    UIkit.modal('#modal_cli_del').show();
+    let text = `${aLangKeys[lang]['cli_client_del1']}${params} ${aLangKeys[lang]['cli_session_del2']}`
+    OpenModDialog({type:'warn',title:text,msg:["cli_client_text"],master_btn:['button_delete','SelectCliDel()'],slave_btn:['button_cancel']})
     localStorage.setItem('del_cli', params)
 }
 
@@ -341,11 +316,13 @@ function RowImg(params) {
 function session_img(session_id,note) {
     onsqlresult = RowImg
     if(location.pathname === '/production/client.tcls'){
-        document.getElementById('pi_retriveSession').innerHTML = `<button key-title="cli_retrive" onclick='rest_session(${session_id},"${note}")' class="uk-button uk-button-primary mdi mdi-arrow-down-thin-circle-outline mdi-rotate-270 uk-button-small" style="font-size:16pt;"></button>
-                                                                  <button key-title="cli_to_pdf" onclick='toProtokoll(${session_id})' class='uk-button mdi mdi-file-pdf-box uk-button-primary uk-button-small' style="font-size:16pt;"></button>`;
+        document.getElementById('details_info').innerHTML = note || session_id
+        document.getElementById('pi_retriveSession').innerHTML = `<button key="cli_to_pdf" onclick='toProtokoll(${session_id})' class='uk-button uk-button-default'><!--protokoll--></button>
+                                                                  <button key="cli_retrive" onclick='rest_session(${session_id},"${note}")' class="uk-button uk-button-primary"><!--fortsetzen--></button>`;
+        UIkit.modal('#modal_details').show(); 
     }
     translatejs();
-    console.log("sql select * from recordings");
+    localStorage.setItem('session_note',note)
     // session.send(`sql select * from recordings where session_id=${session_id}`)
     session.send(`sql SELECT * FROM recordings WHERE analysis=2 AND session_id=${session_id} ORDER BY finished`)
 }
